@@ -5,7 +5,7 @@
 #'
 #' Use \code{summary()} to get a nice formatted \code{data.frame} object.
 #'
-#' @param object lm, glm or lmer model
+#' @param x lm, glm or lmer model
 #' @param R number on bootstrap resamples
 #' @param constants vector of predictors to remain unchanged between models.
 #'                  i.e. vector of variables not subjected to bootstrap analysis.
@@ -24,14 +24,14 @@
 #' summary(da.ave.boot)
 #' }
 
-bootAverageDominanceAnalysis<-function(object,R,constants=c(), terms = NULL, fit.functions="default",null.model=NULL, ...) {
+bootAverageDominanceAnalysis<-function(x,R,constants=c(), terms = NULL, fit.functions="default",null.model=NULL, ...) {
   if (!requireNamespace("boot", quietly = TRUE)) { #nocov start
     stop("boot package needed for this function to work. Please install it.",
          call. = FALSE)
   } #nocov end
   # Extract the data
-  total.data  <- getData(object)
-  da.original <- dominanceAnalysis(object, constants=constants, terms = terms, fit.functions=fit.functions, null.model=null.model, ...)
+  total.data  <- getData(x)
+  da.original <- dominanceAnalysis(x, constants=constants, terms = terms, fit.functions=fit.functions, null.model=null.model, ...)
   preds       <- da.original$predictor
   n.preds     <- length(preds)
   ff          <- da.original$fit.functions
@@ -39,12 +39,12 @@ bootAverageDominanceAnalysis<-function(object,R,constants=c(), terms = NULL, fit
   eg          <- expand.grid(preds,ff)
 
   boot.da<-function(d,i) {
-    ss<-d[i,]
-    da<-dominanceAnalysis(object,constants=constants,terms=terms,fit.functions=fit.functions,data=ss, null.model=null.model,...)
+    boot.new.data<-d[i,]
+    da<-dominanceAnalysis(x,constants=constants,terms=terms,fit.functions=fit.functions, newdata=boot.new.data, null.model=null.model,...)
     as.numeric(sapply(da$contribution.average,I))
   }
 
-  res         <- boot::boot(total.data,boot.da, R=R)
+  res         <- boot::boot(total.data ,boot.da, R=R)
   out         <- list(boot=res, preds=preds, fit.functions=ff, R=R, eg=eg, terms=terms)
   class(out)  <- "bootAverageDominanceAnalysis"
   out
